Module fetch

Module fetch 

Boa’s implementation of JavaScript’s fetch function.

More information:

Modules

headers
The Headers JavaScript class, implemented as JsHeaders.
js_module
JavaScript module containing the fetch types and functions.
request
The Request JavaScript class and adjacent types, implemented as JsRequest.
response
Module containing the Response JavaScript class and its helpers, implemented as JsResponse.
tests
Test types and methods to help with testing the Fetch API.

Structs

BlockingReqwestFetcher
Implementation of Fetcher that uses the blocking reqwest library as the backend.
ErrorFetcher
Implementation of Fetcher which will always reject any fetch.

Traits

Fetcher
A trait for backend implementation of an HTTP fetcher.

Functions

fetch
The fetch function.
register
Register the fetch function in the realm, as well as ALL supporting classes. Pass None as the realm to register globally.