ResponseType

Enum ResponseType 

pub enum ResponseType {
    Basic,
    Cors,
    Error,
    Opaque,
    OpaqueRedirect,
}
The type read-only property of the Response interface contains the type of the response. The type determines whether scripts are able to access the response body and headers.

See https://developer.mozilla.org/en-US/docs/Web/API/Response/type.

Variants



Basic

This applies in any of the following cases:

The request is same-origin. The requested URL’s scheme is data:. The request’s mode is navigate or websocket.

With this type, all response headers are exposed except Set-Cookie.



Cors

The request was cross-origin and was successfully processed using CORS. With this type, only CORS-safelisted response headers are exposed.



Error

A network error occurred. The status property is set to 0, body is null, headers are empty and immutable.



Opaque

A response to a cross-origin request whose mode was set to no-cors. The status property is set to 0, body is null, headers are empty and immutable.



OpaqueRedirect

A response to a request whose redirect option was set to manual and which was redirected by the server. The status property is set to 0, body is null, headers are empty and immutable.

Implementations

Source

impl ResponseType

pub fn to_string(self) -> JsString

Return the JavaScript String representing this response type.