TextEncoder

Enum TextEncoder 

pub enum TextEncoder {
    Utf8,
    Utf16Le,
    Utf16Be,
}
The TextEncodermdn class represents an encoder for a specific method, that is a specific character encoding, like utf-8.

Variants



Utf8

Encode UTF-8 strings into buffers.



Utf16Le

Encode UTF-16 strings (little endian) into buffers.



Utf16Be

Encode UTF-16 strings (big endian) into buffers.

Implementations

Source

impl TextEncoder

pub fn constructor( encoding: Option<JsString>, _options: Option<JsObject>, ) -> JsResult<Self>

The TextEncoder() constructor returns a newly created TextEncoder object.

Errors

This will return an error if the encoding or options are invalid or unsupported.

pub fn encode( &self, text: Option<JsString>, context: &mut Context, ) -> JsResult<JsUint8Array>

The TextEncoder.encode() method takes a string as input, and returns a Uint8Array containing the string encoded using UTF-8.

Errors

This will error if there is an issue creating the Uint8Array or encoding the string itself.