pub fn register<F: Fetcher>(
fetcher: F,
realm: Option<Realm>,
context: &mut Context,
) -> JsResult<()>Expand description
Register the fetch function in the realm, as well as ALL supporting classes.
Pass None as the realm to register globally.
Errors
If any of the classes fail to register, an error is returned.