Function set_timeout
Source pub fn set_timeout(
function_ref: Option<JsFunction>,
delay_in_msec: Option<JsValue>,
rest: JsRest<'_>,
context: &mut Context,
) -> JsResult<u32>
Set a timeout to call the given function after the given delay.
The code version of this function is not supported at the moment.
See MDN.
Errors
Any errors when trying to read the context, converting the arguments or
enqueuing the job.